import 'package:flutter/material.dart';
import 'package:midtrans_helper/midtrans_pay.dart';
import 'package:midtrans_helper/midtrans_success.dart';
import 'package:midtrans_helper/midtrans_view.dart';

import 'midtrans_payment_view.dart';

class Midtrans extends StatefulWidget{
  // production url / sandbox url
  //
  // https://api.sandbox.midtrans.com/v2/
  final url;
  ///```
  ///[{
  ///   "id": "a01",
  ///   "price": 6000,
  ///   "quantity": 1,
  ///   "name": "Apple"
  /// }],
  ///```
  final List itemDetail;
  /// ```
  /// {
  /// "first_name": "Budi",
  /// "last_name": "Susanto",
  /// "email": "budisusanto@example.com",
  /// "phone": "+628123456789",
  /// }
  /// ```
  final Map<String,dynamic> customerDetail;
  /// ```
  /// {
  ///   "first_name": "Budi",
  ///   "last_name": "Susanto",
  ///   "email": "budisusanto@example.com",
  ///   "phone": "0812345678910",
  ///   "address": "Sudirman",
  ///   "city": "Jakarta",
  ///   "postal_code": "12190",
  ///   "country_code": "IDN"
  /// }
  /// ```
  final Map<String,dynamic> alamatPengiriman;
  /// ```
  /// {
  ///   "order_id": "CustOrder-110",
  ///   "gross_amount": 9000,
  /// },
  /// ```
  final Map<String,dynamic> detailTransaksi;
  /// midtrans server key
  final String serverKey;
  Midtrans({
    this.url,
    this.itemDetail,
    this.customerDetail,
    @required this.detailTransaksi,
    this.alamatPengiriman,
    @required this.serverKey
  });
  @override
  _Midtrans createState() => _Midtrans();
}

class _Midtrans extends State<Midtrans>{
  int _currentPage = 0;
  String metode = '';
  PageController _controller = PageController(
    initialPage: 0,
  );

  getDataMethod() async {
    Map<String,dynamic> _data = await MidtransView().getDataSelected();
    return _data;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: [
            Container(
              height: MediaQuery.of(context).size.height * 0.15,
              child: Column(
                children: [
                  SizedBox(height: 16,),
                  Row(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Expanded(
                        flex: 1,
                        child: Container(
                          width: 20,
                          height: 20,
                          child: _currentPage == 0 ? SizedBox() : IconButton(
                            padding: EdgeInsets.all(6),
                            icon: Icon(Icons.chevron_left,color: Colors.black54),
                            onPressed: (){
                              _controller.previousPage(duration: Duration(seconds: 1), curve: Curves.easeInOut);
                              --_currentPage;
                              setState((){});
                            },
                          ), 
                        )
                      ),

                      Expanded(
                        flex: 1,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Container(
                              width: 8,
                              height: 8,
                              margin:EdgeInsets.symmetric(horizontal:8,vertical:12),
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                color: _currentPage == 0 ? Colors.blue : Colors.black.withOpacity(0.2),
                              )
                            ),
                            Container(
                              width: 8,
                              height: 8,
                              margin:EdgeInsets.symmetric(horizontal:8,vertical:12),
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                color: _currentPage == 1 ? Colors.blue : Colors.black.withOpacity(0.2),
                              )
                            ),
                            Container(
                              width: 8,
                              height: 8,
                              margin:EdgeInsets.symmetric(horizontal:8,vertical:12),
                              decoration: BoxDecoration(
                                shape: BoxShape.circle,
                                color: _currentPage == 2 ? Colors.blue : Colors.black.withOpacity(0.2),
                              )
                            ),
                          ],
                        ),
                      ),

                      Expanded(
                        flex: 1,
                        child: SizedBox()
                      ),
                    ],
                  ),

                  SizedBox(height:16),

                  _currentPage == 0 ? Text('PAYMENT METHOD',
                    style: TextStyle(
                      fontWeight: FontWeight.w500,
                      fontFamily: 'Hind',
                      fontSize: 16,
                      color: Colors.black87
                    ),
                  ) : SizedBox(),

                  _currentPage == 1 ? Text('PEMBAYARAN',
                    style: TextStyle(
                      fontWeight: FontWeight.w500,
                      fontFamily: 'Hind',
                      fontSize: 16,
                      color: Colors.black87
                    ),
                  ) : SizedBox(),

                  _currentPage == 2 ? Text('SUKSES',
                    style: TextStyle(
                      fontWeight: FontWeight.w500,
                      fontFamily: 'Hind',
                      fontSize: 16,
                      color: Colors.black87
                    ),
                  ) : SizedBox(),
                  SizedBox(height:16),
                ],
              ),
            ),
            Container(
              height: MediaQuery.of(context).size.height * 0.8,
              child: PageView(
                controller: _controller,
                physics: NeverScrollableScrollPhysics(),
                children: [
                  MidtransView(
                    onnext: () async {
                      _controller.nextPage(duration: Duration(seconds: 1), curve: Curves.easeInOut);
                      ++_currentPage;
                      final data = await getDataMethod();
                      metode = data['name'];
                      setState(() {
                      });
                    },
                  ),
                  MidtransPayment(
                    method: metode ?? '',
                    onnext: () async {
                      final data = await getDataMethod();
                      await MidtransPay(
                        detailTransaksi: widget.detailTransaksi,
                        serverKey: widget.serverKey,
                        id: data['id'],
                        url: widget.url,
                        getStatus: (data,status){
                          if(status){
                            _controller.nextPage(duration: Duration(seconds: 1), curve: Curves.easeInOut);
                            ++_currentPage;
                            setState(() {
                              
                            });
                          }
                        }
                      ).send(context);
                    },
                  ),
                  MidtransSuccess(
                    onnext: (){
                      Navigator.pop(context);
                    },
                  ),
                ],
              ),
            ),
          ],
        )
      ),
    );
  }
}